from niaaml.pipeline_component import PipelineComponent

__all__ = ["PreprocessingAlgorithm"]


class PreprocessingAlgorithm(PipelineComponent):
    r"""Class for implementing preprocessing algorithms.

    Date:
        2020

    Author:
        Luka Pečnik

    License:
        MIT

    See Also:
        * :class:`niaaml.pipeline_component.PipelineComponent`
    """
